@@ -7,30 +7,31 @@ from fastapi import FastAPI
 
 import easyleetcode.config as config
 import easyleetcode.web.server as a_server
+import easyleetcode.web.simple_server as a_simple_server
 import easyleetcode.web.utils as utils
 
 app = FastAPI()
 app.mount("/static", config.statics, name="static")
+app.mount("/python_static", config.python_statics, name="python_files")
+app.mount("/Skulpt", config.python_rstatics, name="pythonr_static")
 
 app.include_router(a_server.router)
+app.include_router(a_simple_server.simple_router)
 
 
-def run(host="127.0.0.1", port=8080, py_cmd_path='python '):
+def run(host="127.0.0.1", port=8080):
     '''
 
     :param host: host
     :param port: port
-    :param py_cmd_path:python exe path/cmd
     :return:
     '''
     print('your host is :', host)
     print('your port is :', port)
-    print('your python execute path is :', py_cmd_path, '(use command:', py_cmd_path, ' xxx.py to run python)')
-    print('If you run error in Windows platform,tell me .Because Windows platform I have\'t test')
 
     config.templates.env.variable_start_string = '{['
     config.templates.env.variable_end_string = ']}'
-    a_server.python_path = py_cmd_path
+
     # every times running,path config.count_day 's count +=1 (running count log)
     utils.add_file_txt_count(config.count_day)
     print('_____running:____')
